Load part of NBM at Census Block from CORI s3 bucket
get_frn_nbm_bl.RdGet all the data related to a FRN. A row in this data represent a census block (2020 vintage).
Usage
get_frn_nbm_bl(frn, release = c("latest", "D23", "J24", "D24", "J25", "D25"))Details
IMPORTANT: We are not counting blocks:
when covered only by satellite servives
and discarding a location when a service of 0/0 download/uploads speeds.
Use get_fcc_dictionary("nbm_block") to get a description of the date.
A FRN is a 10 number strings, ie "0007435902" can also be used to be more specific.
Data Source: FCC Broadband Data Collection