Load part of NBM at Census Block from CORI S3 bucket
get_nbm_bl.RdGet all the data related to a states or county.
Get all the data related to a states or county.
Details
A row in this data represent a census block (2020 vintage).
Use get_fcc_dictionary("nbm_block") to get a description of the date.
Data Source: FCC Broadband Data Collection
A row in this data represent a census block (2020 vintage).
Use get_fcc_dictionary("nbm_block") to get a description of the date.
Data Source: FCC Broadband Data Collection