Load all BSL from NBM dataset for a specific county
get_nbm_county_raw.RdAttention: Depending on the county it can take some times.
Usage
get_nbm_county_raw(
geoid_co,
frn = "all",
release = "2025-06-01",
data_dir = tempdir()
)Details
Get all the BSL from NBM dataset for a specific county specified by it's geoid. A row in this data represent a service per location_id. By default the function will return all the ISP but a specific FRN and the last release. (10 number strings, ie "0007435902") can also be used to be more specific.
Data Source: FCC Broadband Data Collection